==> dde-file-manager_4.4.7.orig.tar.xz: dde-file-manager-4.4.7/dde-desktop/translations/dde-desktop_da.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="da" version="2.1">
<context>
    <name>CanvasGridView</name>
    <message>
        <location filename="../view/canvasgridview.cpp" line="1825"/>
        <source>Icon size</source>
        <translation>Ikonstørrelse</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="1831"/>
        <source>Auto arrange</source>
        <translation>Placér automatisk</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="1839"/>
        <location filename="../view/canvasgridview.cpp" line="1952"/>
        <source>Properties</source>
        <translation>Egenskaber</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="1870"/>
        <source>Display Settings</source>
        <translation>Skærmindstillinger</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="1875"/>
        <source>Corner Settings</source>
        <translation>Hjørneindstillinger</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="1880"/>
        <source>Set Wallpaper</source>
        <translation>Sæt tapet</translation>
    </message>
</context>
<context>
    <name>DesktopItemDelegate</name>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="12"/>
        <source>Tiny</source>
        <translation>Meget lille</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="13"/>
        <source>Small</source>
        <translation>Lille</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="14"/>
        <source>Medium</source>
        <translation>Medium</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="15"/>
        <source>Large</source>
        <translation>Stor</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="16"/>
        <source>Super large</source>
        <translation>Meget stor</translation>
    </message>
</context>
<context>
    <name>WallpaperItem</name>
    <message>
        <location filename="../../dde-wallpaper-chooser/wallpaperitem.cpp" line="90"/>
        <source>Only desktop</source>
        <translation>Kun skrivebord</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/wallpaperitem.cpp" line="93"/>
        <source>Only lock screen</source>
        <translation>Kun låseskærm</translation>
    </message>
</context>
<context>
    <name>ZoneMainWindow</name>
    <message>
        <location filename="../../dde-zone/mainwindow.cpp" line="53"/>
        <source>Fast Screen Off</source>
        <translation>Hurtig skærm fra</translation>
    </message>
    <message>
        <location filename="../../dde-zone/mainwindow.cpp" line="53"/>
        <source>Control Center</source>
        <translation>Kontrolcenter</translation>
    </message>
    <message>
        <location filename="../../dde-zone/mainwindow.cpp" line="53"/>
        <source>All Windows</source>
        <translation>Alle vinduer</translation>
    </message>
    <message>
        <location filename="../../dde-zone/mainwindow.cpp" line="53"/>
        <source>Launcher</source>
        <translation>Starter</translation>
    </message>
    <message>
        <location filename="../../dde-zone/mainwindow.cpp" line="53"/>
        <source>Desktop</source>
        <translation>Skrivebord</translation>
    </message>
    <message>
        <location filename="../../dde-zone/mainwindow.cpp" line="53"/>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <location filename="../../dde-zone/mainwindow.cpp" line="57"/>
        <source>Close Window</source>
        <translation>Luk vindue</translation>
    </message>
</context>
</TS>

==> dde-file-manager_4.4.8.5.orig.tar.xz: dde-file-manager-4.4.8.5/dde-desktop/translations/dde-desktop_da.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="da" version="2.1">
<context>
    <name>CanvasGridView</name>
    <message>
        <location filename="../view/canvasgridview.cpp" line="1825"/>
        <source>Icon size</source>
        <translation>Ikonstørrelse</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="1831"/>
        <source>Auto arrange</source>
        <translation>Placér automatisk</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="1839"/>
        <location filename="../view/canvasgridview.cpp" line="1952"/>
        <source>Properties</source>
        <translation>Egenskaber</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="1870"/>
        <source>Display Settings</source>
        <translation>Skærmindstillinger</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="1875"/>
        <source>Corner Settings</source>
        <translation>Hjørneindstillinger</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="1880"/>
        <source>Set Wallpaper</source>
        <translation>Sæt tapet</translation>
    </message>
</context>
<context>
    <name>DesktopItemDelegate</name>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="12"/>
        <source>Tiny</source>
        <translation>Meget lille</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="13"/>
        <source>Small</source>
        <translation>Lille</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="14"/>
        <source>Medium</source>
        <translation>Medium</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="15"/>
        <source>Large</source>
        <translation>Stor</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="16"/>
        <source>Super large</source>
        <translation>Meget stor</translation>
    </message>
</context>
<context>
    <name>WallpaperItem</name>
    <message>
        <location filename="../../dde-wallpaper-chooser/wallpaperitem.cpp" line="90"/>
        <source>Only desktop</source>
        <translation>Kun skrivebord</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/wallpaperitem.cpp" line="93"/>
        <source>Only lock screen</source>
        <translation>Kun låseskærm</translation>
    </message>
</context>
<context>
    <name>ZoneMainWindow</name>
    <message>
        <location filename="../../dde-zone/mainwindow.cpp" line="53"/>
        <source>Fast Screen Off</source>
        <translation>Hurtig skærm fra</translation>
    </message>
    <message>
        <location filename="../../dde-zone/mainwindow.cpp" line="53"/>
        <source>Control Center</source>
        <translation>Kontrolcenter</translation>
    </message>
    <message>
        <location filename="../../dde-zone/mainwindow.cpp" line="53"/>
        <source>All Windows</source>
        <translation>Alle vinduer</translation>
    </message>
    <message>
        <location filename="../../dde-zone/mainwindow.cpp" line="53"/>
        <source>Launcher</source>
        <translation>Starter</translation>
    </message>
    <message>
        <location filename="../../dde-zone/mainwindow.cpp" line="53"/>
        <source>Desktop</source>
        <translation>Skrivebord</translation>
    </message>
    <message>
        <location filename="../../dde-zone/mainwindow.cpp" line="53"/>
        <source>None</source>
        <translation>Intet</translation>
    </message>
    <message>
        <location filename="../../dde-zone/mainwindow.cpp" line="57"/>
        <source>Close Window</source>
        <translation>Luk vindue</translation>
    </message>
</context>
</TS>
